summaryrefslogtreecommitdiffstats
path: root/cypress_test/integration_tests/desktop
diff options
context:
space:
mode:
authorGökay Şatır <gokaysatir@gmail.com>2023-05-12 15:25:37 +0300
committerGökay ŞATIR <gokaysatir@gmail.com>2023-05-13 15:10:08 +0300
commit9018e3f174eaec9d15ac4666f1640d7774f41c0f (patch)
treea7419705b7e3111e9d33bfa941fc229f0141c839 /cypress_test/integration_tests/desktop
parentEnable skipped tests in desktop writer top toolbar spec. (diff)
downloadonline-9018e3f174eaec9d15ac4666f1640d7774f41c0f.tar.gz
online-9018e3f174eaec9d15ac4666f1640d7774f41c0f.zip
Enable one writer desktop test in track changes spec.
Signed-off-by: Gökay Şatır <gokaysatir@gmail.com> Change-Id: I3d465f331bda1f2619939e8d6d9ca89ef95a0026
Diffstat (limited to 'cypress_test/integration_tests/desktop')
-rw-r--r--cypress_test/integration_tests/desktop/writer/track_changes_spec.js39
1 files changed, 8 insertions, 31 deletions
diff --git a/cypress_test/integration_tests/desktop/writer/track_changes_spec.js b/cypress_test/integration_tests/desktop/writer/track_changes_spec.js
index 21355c745b..8f0d121943 100644
--- a/cypress_test/integration_tests/desktop/writer/track_changes_spec.js
+++ b/cypress_test/integration_tests/desktop/writer/track_changes_spec.js
@@ -1,4 +1,4 @@
/* global describe it cy beforeEach require afterEach*/
var helper = require('../../common/helper');
@@ -16,8 +16,10 @@ describe(['tagdesktop', 'tagnextcloud', 'tagproxy'], 'Track Changes', function (
function confirmChange(action) {
cy.cGet('#menu-editmenu').click();
- cy.cGet('#menu-changesmenu').click();
- cy.cGet('#menu-changesmenu').contains(action).click();
+ cy.cGet('#menu-changesmenu').should($el => { expect(Cypress.dom.isDetached($el)).to.eq(false); }).click();
+ cy.cGet('#menu-changesmenu').should($el => { expect(Cypress.dom.isDetached($el)).to.eq(false); }).contains(action).click();
+ cy.cGet('body').type('{esc}');
+ cy.cGet('#menu-changesmenu').should('not.be.visible');
}
//enable record for track changes
@@ -26,8 +28,7 @@ describe(['tagdesktop', 'tagnextcloud', 'tagproxy'], 'Track Changes', function (
cy.cGet('#menu-changesmenu').click();
cy.cGet('#menu-changesmenu').contains('Record').click();
- //if we don't wait , the test will fail in CLI
- cy.wait(200);
+ cy.cGet('body').type('{esc}');
cy.cGet('#menu-editmenu').click();
cy.cGet('#menu-changesmenu').click();
@@ -38,47 +39,23 @@ describe(['tagdesktop', 'tagnextcloud', 'tagproxy'], 'Track Changes', function (
}
it('Accept All', function () {
-
helper.typeIntoDocument('Hello World');
-
enableRecord();
-
helper.clearAllText();
- //if we don't wait , the test will fail in CLI
- cy.wait(200);
-
helper.selectAllText();
-
confirmChange('Accept All');
-
- cy.wait(200);
-
helper.typeIntoDocument('{ctrl}a');
-
helper.textSelectionShouldNotExist();
});
- it.skip('Reject All', function () {
-
+ it('Reject All', function () {
helper.typeIntoDocument('Hello World');
-
enableRecord();
-
helper.clearAllText();
-
- //if we don't wait , the test will fail in CLI
- cy.wait(600);
-
helper.selectAllText();
-
confirmChange('Reject All');
-
- cy.wait(200);
-
- cy.cGet('.leaflet-layer').click();
-
+ cy.cGet('#document-container').click();
helper.selectAllText();
-
helper.expectTextForClipboard('Hello World');
});
});
@@ -1,4 +1,4 @@
-/* global describe it cy beforeEach require afterEach*/
+/* global describe it cy beforeEach require afterEach Cypress expect */
var helper = require('../../common/helper');